import paraview.vtk as vtk
import numpy as np

mesh = self.GetPolyDataInput()
center = mesh.GetCenter()

pdd = vtk.vtkImplicitPolyDataDistance()
pdd.SetInput(mesh)

# Setup a grid
points = vtk.vtkPoints()
step = 0.1
for x in np.arange(center[0] - 2,center[0] + 2, step):
	for y in np.arange(center[1] - 2,center[1] + 2, step):
		for z in np.arange(center[2] - 2,center[2] + 2, step):
			points.InsertNextPoint(x, y, z)

# Add distances to each point
signedDistances = vtk.vtkFloatArray()
signedDistances.SetNumberOfComponents(1)
signedDistances.SetName('SignedDistances')

# Evaluate the signed distance function at all of the grid points
for pointId in range(points.GetNumberOfPoints()):
	p = points.GetPoint(pointId)
	signedDistance = pdd.EvaluateFunction(p)
	signedDistances.InsertNextValue(signedDistance)

polyData = vtk.vtkPolyData()
polyData.SetPoints(points)
polyData.GetPointData().SetScalars(signedDistances)

output =  self.GetPolyDataOutput();
output.CopyStructure(polyData)
output.GetPointData().AddArray(signedDistances)
output.GetPointData().SetActiveScalars('SignedDistances')